<?php

/**
 * This is the model class for table "{{member}}".
 *
 * The followings are the available columns in table '{{member}}':
 * @property integer $id
 * @property integer $groupid
 * @property string $firstname
 * @property string $lastname
 * @property integer $membersince
 * @property integer $position
 *
 * The followings are the available model relations:
 * @property Group $group
 */
class Member extends CActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @return Member the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return '{{member}}';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('groupid, membersince, position', 'numerical', 'integerOnly'=>true),
			array('firstname, lastname', 'length', 'max'=>40),
            array('lastname', 'required'),
            array('flags', 'checkArray'),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('id, groupid, firstname, lastname, membersince, position', 'safe', 'on'=>'search'),
		);
	}

    public function checkArray($attribute)
    {
        if(!empty($this->$attribute) && !is_array($this->$attribute))
           $this->addError($this->$attribute,'Must be an array');
    }

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'group' => array(self::BELONGS_TO, 'Group', 'groupid'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'groupid' => 'Groupid',
			'firstname' => 'Firstname',
			'lastname' => 'Lastname',
			'membersince' => 'Membersince',
			'position' => 'Position',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('groupid',$this->groupid);
		$criteria->compare('firstname',$this->firstname,true);
		$criteria->compare('lastname',$this->lastname,true);
		$criteria->compare('membersince',$this->membersince);
		$criteria->compare('position',$this->position);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}


    /*
     * Convert the flags array to string
     */
    public function beforeSave()
    {
        if(parent::beforeSave())
        {
            if(!empty($this->flags) && is_array($this->flags))
                $this->flags = implode(',',$this->flags);

            return true;
        }

        return false;
    }

   /*
    * Convert the flags string to array
    */
   public function afterFind()
   {
       $this->flags = empty($this->flags) ? array() : explode(',',$this->flags);
   }
}